yakumo.cinder.v2.consistency_group_snapshot.Manager

Package yakumo :: Package cinder :: Package v2 :: Module consistency_group_snapshot :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

manager class for consistency group snapshot on Block Storage V2 API

Nested Classes | [hide private]
| resource_class resource class for consistency group snapshot on Block Storage V2 API

Instance Methods | [hide private]
yakumo.cinder.v2.consistency_group_snapshot.Resource |
create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, source_cg=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, user=`'``__UNDEF__``'`, status=`'``__UNDEF__``'`) Create a consistency group snapshot | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``volume``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _hidden_methods = ``[``'``update``'``]``
| _json_resource_key = ``'``cgsnapshot``'``
| _json_resources_key = ``'``cgsnapshots``'``
| _url_resource_list_path = ``'``/cgsnapshots/detail``'``
| _url_resource_path = ``'``/cgsnapshots``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_id_attr`, `_update_method`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, source_cg=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, user=`'``__UNDEF__``'`, status=`'``__UNDEF__``'`) | source code
Create a consistency group snapshot Parameters: `name` (str) - Consistency group name `description` (str) - Description `source_cg` (yakumo.cinder.v2.consistency_group.Resource) - Source consistency group `project` (yakumo.project.Resource) - Project (optional) `user` (yakumo.user.Resource) - User (optional) Returns: yakumo.cinder.v2.consistency_group_snapshot.Resource Created consistency group snapshot Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'display_description', mapper.Noop), ('source_cg', 'consistencygr
      oup_id', mapper.List(mapper.Resource('cinder.consistency_group'))), ('
      project', 'project_id', mapper.List(mapper.Resource('project'))), ('us
      er', 'user_id', mapper.List(mapper.Resource('user'))), ('status', 'sta
      tus', mapper.Noop), ('created_at', 'created_at', mapper.DateTime),]